==> ZenTaoPMS.biz7.0.php5.4_5.6.zip: zentaopms/extension/max/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPsnR5AXJeEoFak+1YpK19FoEcemwuB7WYYGfT9OCme2rvxyEvcvuSz0O6Xvvkv4bMJFBJ8by
V/10E1Z6VAB/D9MALtidphAXGQKFy84HPbeNdmX+MeEXHXLJNEalMCFrMhstAskNYjebCqMWjS7y
9FF5yLa0H3zqhx6TwTIy/6/vjlMH1vXwLgnPhrPwaqddziv6AWoCOwRWboCsic9UC30A/q+E6vwy
73tCYZr/BujU82/baenUOMIRoHTnhMC6ZqvG7F7A1PofaAALXxWlkBykRJ1NmXu1/lqCUSsxmEle
Rj7LePsTZPTkOUVBk7Jwo8g7b6JWM/81elcNXkoE7RYJMsB0SNAoRce+ulMz7UhuP+5NRptfaqqb
Ds+wGP79eNR6f1rUbIpjBQCPnn97Jm56Bw1xMzjUY438U2NnGaJFFTt20Ul1o4JvuW4eWuRH69Ps
9TUgWBofdXDdT9vz1pNg4SHD+svOkp22QPCmaTkHGU1WvrksQoCxvG==

==> ZenTaoPMS.biz7.3.php5.4_5.6.zip: zentaopms/extension/max/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPt0J6hyk+FwmZwUFd0c5GnJ8/Z+M2OLk5nAl7LMpHtvEq0mg/6Ov6R2Ji644pZevXHES8+7D
2iOqkm/UpK8GT+IMXIsLtj06K6iAt3jsbwI4GiPrkEjwnGoqeRw0OFI6JyFSNKeasp2s8weAATlj
qUal75GSY6BVIc/QbZLuyIq196mJTYvv291dQVTFG6qER/WfZm5crJDlozxaM6Etv++e5uVcXdL2
FyC7RYyRXoNr/tL3Nwz0VuK36sbk8rAXx0P4gsrU07ZdzE0LuKPJZUoGJwH2VELtxiWWOp1t26vH
MH14dmgak0vcZGinz7HJkPIIrO+TCJx1gfuu2+EK7VWA6eNffIxgSoEKRghGnxvZ2s2DeOZ9NNMo
mYEJe8KJgW9ecN+/bOMIFuDsu4H8sw6XWk8JF/hNxp7vLgBVvqDgDk/3iGYplBrNGDBm5PRsFrLH
V9L/Ykf3eUCCsxL3CRsvdhAlBFEYNpPC3ErMoUtncVsUwRKbepyg724=
